/******************************************************************************
;  *       @型号                 : MC51F7424
;  *       @创建日期             : 2023.02.01
;  *       @公司/作者            : SINOMCU.COM-AE
;  *       @晟矽微官网           : http://www.sinomcu.com/
;  *       @版权                 : 晟矽微电 版权所有.
;  *----------------------摘要描述---------------------------------
;  * void UART_PinInit(void) 引脚初始化;
;  * void UART1_Init(uint32_t uart_baud) 初始化UART1;
;  * char putchar(char tx_data) 重定向printf到UART1;
;  * void UART1_ISR(void) UART1中断服务程序.
******************************************************************************/

#include "User_Def.h"

/**
  * @brief  uart pin initialization
  * @param  
  * @retval 
  * @note
  *     P04(UART1_TX)
  */
void UART_PinInit(void) {
  P04D = 1;
  TX1_MAP = 0x04;
}

/**
  * @brief  uart1 initialization,baud used BRG
  * @param  uint16_t baud rate,unit bps
  * @retval 
  */
void UART1_Init(uint32_t uart_baud) {
  uint16_t xdata baud_rate_cacl=0; 
  UART_PinInit();

  SET_UART1EN();                       /*使能UART1 */

  Uart1_Mode_Set(UART_MODE_01);        /*方式1,8bit */ 
  Uart1_REN_set();                     /*允许接收 */

  baud_rate_cacl =  (65536 - FSYS_CLOCK/16/uart_baud);    
  UART1_BGR_En();                      /*使能波特率发生器*/
  BRGL=(uint8_t)(baud_rate_cacl);
  BRGH=(uint8_t)(baud_rate_cacl >>8);
 
  //UART1_INTR_En();                   /*打开UART1中断*/
}

/**
  * @brief  retarget printf to uart1
  * @param  char,one char of send buff 
  * @retval char,send char
  */
char putchar(char tx_data) {
#if(defined(EN_PRINT_UART) && EN_PRINT_UART) 
  SBUF_1 = tx_data;                    /*写数据到UART数据寄存器*/
  while (!Read_Uart1_TI()) { ;}        /*等待前面的数据发送完成*/
  Uart1_TI_clear();
#endif
  return tx_data;
}

/**
  * @brief  uart1 interrupt function
  * @param  
  * @retval 
  */
void UART1_ISR(void) interrupt UART1_IRQn {
  if(Read_Uart1_RI()) {
    Uart1_RI_clear();
  }
  if(Read_Uart1_TI()) {
    Uart1_TI_clear();
  }
}
/**************************** end of file *********************************************/